/*
 * Config header for libsysfs example programs.
 */

#ifndef SYSFS_CONFIG_H
#define SYSFS_CONFIG_H 1

#ifndef _GNU_SOURCE
#define _GNU_SOURCE 1
#endif

#ifndef _POSIX_SOURCE
#define _POSIX_SOURCE 1
#endif

#ifndef _FILE_OFFSET_BITS
#define _FILE_OFFSET_BITS 64
#endif

#endif
